"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ApiGatewayV2Envelope = void 0;
const apigwv2_js_1 = require("../schemas/apigwv2.js");
const envelope_js_1 = require("./envelope.js");
const errors_js_1 = require("../errors.js");
/**
 * API Gateway V2 envelope to extract data within body key
 */
class ApiGatewayV2Envelope extends envelope_js_1.Envelope {
    static parse(data, schema) {
        return super.parse(apigwv2_js_1.APIGatewayProxyEventV2Schema.parse(data).body, schema);
    }
    static safeParse(data, schema) {
        const parsedEnvelope = apigwv2_js_1.APIGatewayProxyEventV2Schema.safeParse(data);
        if (!parsedEnvelope.success) {
            return {
                success: false,
                error: new errors_js_1.ParseError('Failed to parse API Gateway V2 envelope', {
                    cause: parsedEnvelope.error,
                }),
                originalEvent: data,
            };
        }
        const parsedBody = super.safeParse(parsedEnvelope.data.body, schema);
        if (!parsedBody.success) {
            return {
                success: false,
                error: new errors_js_1.ParseError('Failed to parse API Gateway V2 envelope body', {
                    cause: parsedBody.error,
                }),
                originalEvent: data,
            };
        }
        return parsedBody;
    }
}
exports.ApiGatewayV2Envelope = ApiGatewayV2Envelope;
