import { z, type ZodSchema } from 'zod';
import { Envelope } from './envelope.js';
import { ParsedResult } from '../types/index.js';
/**
 * Kafka event envelope to extract data within body key
 * The record's body parameter is a string, though it can also be a JSON encoded string.
 * Regardless of its type it'll be parsed into a BaseModel object.
 *
 * Note: Records will be parsed the same way so if model is str,
 * all items in the list will be parsed as str and not as JSON (and vice versa)
 */
export declare class KafkaEnvelope extends Envelope {
    static parse<T extends ZodSchema>(data: unknown, schema: T): z.infer<T>;
    static safeParse<T extends ZodSchema>(data: unknown, schema: T): ParsedResult;
}
//# sourceMappingURL=kafka.d.ts.map