import { z, type ZodSchema } from 'zod';
import { Envelope } from './envelope.js';
import type { ParsedResult } from '../types/index.js';
/**
 * Kinesis Firehose Envelope to extract array of Records
 *
 *  The record's data parameter is a base64 encoded string which is parsed into a bytes array,
 *  though it can also be a JSON encoded string.
 *  Regardless of its type it'll be parsed into a BaseModel object.
 *
 *  Note: Records will be parsed the same way so if model is str,
 *  all items in the list will be parsed as str and not as JSON (and vice versa)
 *
 *  https://docs.aws.amazon.com/lambda/latest/dg/services-kinesisfirehose.html
 */
export declare class KinesisFirehoseEnvelope extends Envelope {
    static parse<T extends ZodSchema>(data: unknown, schema: T): z.infer<T>;
    static safeParse<T extends ZodSchema>(data: unknown, schema: T): ParsedResult;
}
//# sourceMappingURL=kinesis-firehose.d.ts.map