import { Envelope } from './envelope.js';
import { z, type ZodSchema } from 'zod';
import type { ParsedResult } from '../types/index.js';
/**
 * Kinesis Data Stream Envelope to extract array of Records
 *
 * The record's data parameter is a base64 encoded string which is parsed into a bytes array,
 * though it can also be a JSON encoded string.
 * Regardless of its type it'll be parsed into a BaseModel object.
 *
 * Note: Records will be parsed the same way so if model is str,
 * all items in the list will be parsed as str and not as JSON (and vice versa)
 */
export declare class KinesisEnvelope extends Envelope {
    static parse<T extends ZodSchema>(data: unknown, schema: T): z.infer<T>;
    static safeParse<T extends ZodSchema>(data: unknown, schema: T): ParsedResult;
}
//# sourceMappingURL=kinesis.d.ts.map