import { Envelope } from './envelope.js';
import { VpcLatticeSchema } from '../schemas/index.js';
import { ParseError } from '../errors.js';
/**
 * Amazon VPC Lattice envelope to extract data within body key
 */
export class VpcLatticeEnvelope extends Envelope {
    static parse(data, schema) {
        const parsedEnvelope = VpcLatticeSchema.parse(data);
        return super.parse(parsedEnvelope.body, schema);
    }
    static safeParse(data, schema) {
        const parsedEnvelope = VpcLatticeSchema.safeParse(data);
        if (!parsedEnvelope.success) {
            return {
                success: false,
                error: new ParseError('Failed to parse VpcLattice envelope', {
                    cause: parsedEnvelope.error,
                }),
                originalEvent: data,
            };
        }
        const parsedBody = super.safeParse(parsedEnvelope.data.body, schema);
        if (!parsedBody.success) {
            return {
                success: false,
                error: new ParseError('Failed to parse VpcLattice envelope body', {
                    cause: parsedBody.error,
                }),
                originalEvent: data,
            };
        }
        return parsedBody;
    }
}
